@@ -1,14 +1,14 @@
 ###
-#  by Anarion 
+#  by Anarion
 #  anarion@7a69ezine.org
 package DNS::TinyDNS::dnscache;
 
 our @ISA = qw(DNS::TinyDNS);
-our $VERSION = "0.15";
+our $VERSION = '0.22';
 
 =head1 NAME
 
-DNS::TinyDNS::dnscache - Perl extension for manipulating dnscache from djbdns 
+DNS::TinyDNS::dnscache - Perl extension for manipulating dnscache from djbdns
 
 =head1 SYNOPSIS
 
@@ -45,9 +45,13 @@ This module will allow you to manipulate djbdns dnscache files.
 
 =back
 
-Returns a list of all the ips/nets allowed to use this cache server
+Returns a list/reference of all the ips/nets allowed to use this cache server
 
-        my @ips=$dnscache->list_ips;
+        # Returns a list
+        my @ips = $dnscache->list_ips;
+
+        # Returns an array ref
+        my $ips = $dnscache->list_ips;
 
 =over 4
 
@@ -79,9 +83,13 @@ This deletes C<All entries> of 10.0.0.0/24 allowed to use this dnscache.
 
 =back
 
-Returns a list of the root servers
+Returns a list/reference of the root servers
 
-        my @root_servers=$dnscache->list_servers;
+        # Returns a list
+        my @root_servers = $dnscache->list_servers;
+
+        # Returns an array ref
+        my $root_servers = $dnscache->list_servers;
 
 =over 4
 
@@ -119,6 +127,18 @@ You can set/get this vars:
 For further information about every var, consult djbdns cache documentation at
 C<http://cr.yp.to/>
 
+=head1 AUTHOR
+
+Anarion: anarion@7a69ezine.org
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=head1 SEE ALSO
+
+L<DNS::TinyDNS>.
+L<DNS::TinyDNS::dnsserver>.
+
 =cut
 
 use Carp;
@@ -174,8 +194,8 @@ sub del_ip
                 return 0;
         }
 
-        unlink("$dir/$ip") 
-		or carp "Warning: That ip wasn't in the db";   
+        unlink("$dir/$ip")
+                or carp "Warning: That ip wasn't in the db";#'
 }
 
 sub list_ips
@@ -184,18 +204,18 @@ sub list_ips
         my $dir = $self->{dir} . "/root/ip";
         my @ips;
         local *FILE;
-        
+
         unless($self->{dir} and -d $dir)
         {
                 carp "ERROR: dnscache directory not set";
                 return 0;
         }
-        
-        opendir(FILE,$dir) 
+
+        opendir(FILE,$dir)
             or carp "ERROR: Cant read $dir";
         @ips = grep { index($_,".") != 0 } readdir(FILE);
         closedir(FILE);
-        return @ips;
+        return wantarray ? @ips : \@ips;
 }
 
 sub add_server
@@ -204,22 +224,22 @@ sub add_server
         my $file = $self->{dir} . '/root/servers/@';
         my @array;
         local *FILE;
-        
+
         unless($self->{dir} and -f $file)
         {
                 carp "ERROR: dnscache directory not set";
                 return 0;
         }
-        
-        open(FILE, ">>$file")         
+
+        open(FILE, ">>$file")
             or carp "ERROR: Cant write to $file" and return;
-	flock(FILE,LOCK_EX) 
+        flock(FILE,LOCK_EX)
             or carp "ERROR: Cant lock $file";
         seek(FILE,0,2)
             or carp "ERROR: Cant seek $file";
         print FILE "$ip\n";
         close(FILE)
-	    or carp "ERROR: Cant close $file";
+                or carp "ERROR: Cant close $file";
 }
 
 sub del_server
@@ -228,32 +248,32 @@ sub del_server
         my $file = $self->{dir} . '/root/servers/@';
         my @array;
         local (*FILENEW,*FILEOLD);
-        
+
         unless($self->{dir} and -f $file)
         {
-                carp "ERROR: $self->{dir} isn't a dnscache directory";
+                carp "ERROR: $self->{dir} isn't a dnscache directory";#'
                 return 0;
         }
 
-        open(FILENEW, ">$self->{dir}/root/servers/new")         
-	    or carp "ERROR: Cant write to $self->{dir}/root/servers/new" and return;
-	flock(FILENEW,LOCK_EX) 
+        open(FILENEW, ">$self->{dir}/root/servers/new")
+                or carp "ERROR: Cant write to $self->{dir}/root/servers/new" and return;
+        flock(FILENEW,LOCK_EX)
             or carp "ERROR: Cant lock $self->{dir}/root/servers/new";
         open(FILEOLD,$file)
             or carp "ERROR: Cant read from $file" and return;
-	flock(FILEOLD,LOCK_EX) 
+        flock(FILEOLD,LOCK_EX)
             or carp "ERROR: Cant lock $file";
         seek(FILEOLD,0,0)
             or carp "ERROR: Cant seek $file";
-	seek(FILENEW,0,0)
-	   or carp "ERROR: Cant seek $self->{dir}/root/servers/new";
+        seek(FILENEW,0,0)
+                or carp "ERROR: Cant seek $self->{dir}/root/servers/new";
         while(my $line = <FILEOLD>)
         {
-		syswrite(FILENEW,$line) if index($line,$ip) == -1;
+                syswrite(FILENEW,$line) if index($line,$ip) == -1;
         }
-	close(FILENEW)
-	    or carp "ERROR: Cant close $self->{dir}/root/servers/new";
-	close(FILEOLD)
+        close(FILENEW)
+                or carp "ERROR: Cant close $self->{dir}/root/servers/new";
+        close(FILEOLD)
             or carp "ERROR: Cant close $self->{dir}/root/servers/new";
         unlink($file)
             or carp "ERROR: Cant unlink $self->{dir}/root/servers/new";
@@ -267,23 +287,23 @@ sub list_servers
         my $file = $self->{dir} . '/root/servers/@';
         my @root_servers;
         local *FILE;
-        
+
         unless($self->{dir} and -f $file)
         {
                 carp "ERROR: dnscache directory not set ($file)";
                 return 0;
         }
-        
-        open(FILE,$file) 
+
+        open(FILE,$file)
             or carp "ERROR: Cant read from $file";
         flock(FILE,LOCK_EX)
             or carp "Cant lock $file";
         seek(FILE,0,0)
-            or carp "ERROR: Cant seek $file";  
+            or carp "ERROR: Cant seek $file";
         chomp(@root_servers=<FILE>);
         close(FILE)
             or carp "ERROR: Cant close $file";
-        return @root_servers;
+        return wantarray ? @root_servers : \@root_servers;
 }
 
 1;
